# THIS FILE IS GENERATED FROM TRAITS SETUP.PY
version = '5.1.1'
full_version = '5.1.1'
git_revision = 'e2fe1b95dc0660321350aab09428a811922acc78'
is_released = True

if not is_released:
    version = full_version
